@@ -5,14 +5,12 @@ from .base import MarkerBase
 class MarkerEnvBase(MarkerBase):
 
     def exec(self, env, command, marker_node, marker_set):
-        argv = self.split(command, True)
-        args, _ = self.cmd2ak(argv[1:3])
-        args, _ = self.var_map_batch(env, *args)
+        argv = self.split_raw(command, 2)[1:]
         environ = self.get_environ(env)
-        if len(args) == 1:
-            environ.pop(args[0], None)
-        elif len(args) == 2:
-            environ[args[0]] = args[1]
+        if len(argv) == 1:
+            environ.pop(argv[0], None)
+        elif len(argv) == 2:
+            environ[argv[0]] = argv[1]
         else:
             environ.clear()
 
